<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=my
// ** ne pas modifier le fichier **

return [

	// D
	'diff_para_ajoute' => 'စာပိုဒ်ထပ်ဖြည့်ပါ',
	'diff_para_deplace' => 'စာပိုဒ်ရွေ့ပါ',
	'diff_para_supprime' => 'စာပိုဒ်ဖျက်ပစ်ပါ',
	'diff_texte_ajoute' => 'စာသားထပ်ထည့်ပါ',
	'diff_texte_deplace' => 'စာသားရွေ့ပါ',
	'diff_texte_supprime' => 'စာသားဖျက်ပစ်ပါ',

	// I
	'info_historique' => 'ပြန်လည်ကြည့်ရှုခြင်း',
	'info_historique_lien' => 'မူကွဲများစာရင်းကို ပြပါ',
	'info_historique_titre' => 'ခြေရာပြန်ကောက်ကြည့်ရန်',

	// V
	'version_initiale' => 'မူကွဲအစ',
];
